ggf
===

|PyPI Version| |Tests Status Linux| |Coverage Status| |Docs Status|


**ggf** is a Python 3 library for computing global geometric factors and
corresponding stresses experienced by dielectric objects in the
optical stretcher.


Documentation
-------------

The documentation, including the code reference and examples, is available on
`ggf.readthedocs.io <https://ggf.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install ggf


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |PyPI Version| image:: http://img.shields.io/pypi/v/ggf.svg
   :target: https://pypi.python.org/pypi/ggf
.. |Tests Status Linux| image:: http://img.shields.io/travis/GuckLab/ggf.svg?label=tests_linux
   :target: https://travis-ci.org/GuckLab/ggf
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/GuckLab/ggf/master.svg
   :target: https://codecov.io/gh/GuckLab/ggf
.. |Docs Status| image:: https://readthedocs.org/projects/ggf/badge/?version=latest
   :target: https://readthedocs.org/projects/ggf/builds/

